@@ -40,12 +40,16 @@ def initialize(reset=False):
     if reset or (_EXT_MANAGER is None):
         _EXT_MANAGER = extension.ExtensionManager(namespace='os_vif',
                                                   invoke_on_load=False)
+        loaded_plugins = []
         for plugin_name in _EXT_MANAGER.names():
             cls = _EXT_MANAGER[plugin_name].plugin
             obj = cls.load(plugin_name)
-            LOG.info("Loaded VIF plugin class '%s' with name '%s'",
-                     cls, plugin_name)
+            LOG.debug(("Loaded VIF plugin class '%(cls)s' "
+                       "with name '%(plugin_name)s'"),
+                      {'cls': cls, 'plugin_name': plugin_name})
+            loaded_plugins.append(plugin_name)
             _EXT_MANAGER[plugin_name].obj = obj
+        LOG.info(_LI("Loaded VIF plugins: %s"), ", ".join(loaded_plugins))
 
 
 def plug(vif, instance_info):
@@ -114,12 +118,21 @@ def unplug(vif, instance_info):
         raise os_vif.exception.UnplugException(vif=vif, err=err)
 
 
-def host_info():
+def host_info(permitted_vif_type_names=None):
     """
+    :param permitted_vif_type_names: list of VIF object names
+
     Get information about the host platform configuration to be
     provided to the network manager. This will include information
     about what plugins are installed in the host
 
+    If permitted_vif_type_names is not None, the returned HostInfo
+    will be filtered such that it only includes plugins which
+    support one of the listed VIF types. This allows the caller
+    to filter out impls which are not compatible with the current
+    usage configuration. For example, to remove VIFVHostUser if
+    the guest does not support shared memory.
+
     :returns: a os_vif.host_info.HostInfo class instance
     """
 
@@ -128,7 +141,10 @@ def host_info():
 
     plugins = [
         _EXT_MANAGER[name].obj.describe()
-        for name in _EXT_MANAGER.names()
+        for name in sorted(_EXT_MANAGER.names())
     ]
 
-    return os_vif.objects.host_info.HostInfo(plugin_info=plugins)
+    info = os_vif.objects.host_info.HostInfo(plugin_info=plugins)
+    if permitted_vif_type_names is not None:
+        info.filter_vif_types(permitted_vif_type_names)
+    return info
